{#
  Copyright (C) 2020-2024 Graz University of Technology.

  invenio-theme-iform is free software; you can redistribute it and/or
  modify it under the terms of the MIT License; see LICENSE file for more
  details.
#}

<div class="ui segment" style="padding-bottom: 10px;">
  <h4>{{ _("Good reasons to use the I-Form Repository") }}</h4>

  <ul>
    <li><strong>{{_("Safe") }}</strong> &mdash; {{_("Your research results are permanently available.") }}</li>
    <li><strong>{{_("Trusted") }}</strong> &mdash; {{_("A service from I-Form, developed in cooperation with CERN.") }}</li>
    <li><strong>{{_("Citeable") }}</strong> &mdash; {{_("Every upload is assigned a Digital Object Identifier (DOI).") }}</li>
    <li><strong>{{_("No waiting time") }}</strong> &mdash; {{_("Uploads are made available online as soon as you hit publish. Your DOI is registered within seconds.") }}</li>
    <li><strong>{{_("Open or closed") }}</strong> &mdash; {{_("You determine the visibility of your uploads. A restricted access mode is possible.") }}</li>
    <li><strong>{{_("Versioning") }}</strong> &mdash; {{_("Easily update your dataset with the versioning feature.") }}</li>
    <li><strong>{{_("Usage statistics") }}</strong> &mdash; {{ _("All uploads display standards compliant usage statistics. ") }} <a href="help/statistics">({{ _("More") }})</a></li>
  </ul>
</div>
