{#
  Copyright (C) 2020-2023 Graz University of Technology.

  invenio-theme-iform is free software; you can redistribute it and/or
  modify it under the terms of the MIT License; see LICENSE file for more
  details.
#}

{%- block css %}
  {{ webpack['invenio-theme-iform-theme.css'] }}
{%- endblock %}

{%- block javascript %}
  {{ webpack['invenio-theme-iform-js.js'] }}
{%- endblock javascript %}

<div class="spacer"></div>

<footer id="footer" class="footer-bottom">
  <div class="ui container">
    <div class="ui grid">
      <div class="doubling four column row">
        <div class="column">
          <h2>{{ _("Repository") }}</h2>
          <div class="ui list">
            <div class="item">
              <a href="https://tu-graz-library.github.io/docs-repository" title="Repository documentation"
                 target="_blank">
                 {{ _("Documentation") }} <i class="external alternate icon"></i>
              </a>
            </div>

            <div class="item">
              <a href="{{ url_for('invenio_config_iform.guide') }}"
                 title="Quick guide" target="_blank">
                 {{ _("Reference Guide") }} <i class="download icon"></i>
              </a>
            </div>

            <div class="item">
              <a href="{{ url_for('invenio_app_rdm.help_search') }}"
                 title="Search guide">
                 {{ _("Search Guide") }}<i class="angle right icon"></i>
              </a>
            </div>

            <div class="item">
              <a href="{{ url_for('invenio_config_iform.gdpr') }}"
                 title="General Data Protection Rights" target="_blank">
                 {{ _("Data Protection") }} <i class="download icon"></i>
              </a>
            </div>

            <div class="item">
              <a href="{{ url_for('invenio_config_iform.terms') }}"
                 title="Terms and Conditions" target="_blank">
                 {{ _("Terms and Conditions") }} <i class="download icon"></i>
              </a>
            </div>
          </div>
        </div>


        <div class="column">
          <h2>{{ _("Features") }}</h2>

          <div class="ui list">
            <div class="item">{{ _("Scalability") }}</div>
            <div class="item">{{ _("Institutional integration") }}</div>
            <div class="item">{{ _("Next Generation Repository") }}</div>
            <div class="item">{{ _("Repository Profiles") }}</div>
            <div class="item">{{ _("Resilient") }}</div>
          </div>
        </div>


        <div class="column">
          <h2>{{ _("Connected Services") }}</h2>
          <div class="ui list">
            <div class="item">
              <a href="https://pure.tugraz.at" title="PURE" target="_blank">
                {{ _("PURE") }} <i class="external alternate icon"></i>
              </a>
            </div>

            <div class="item">
              <a href="http://campusonline.tugraz.at" title="CAMPUS online" target="_blank">
                {{ _("CampusOnline") }} <i class="external alternate icon"></i>
              </a>
            </div>

            <div class="item">
              <a href="https://rdm.i-form.ie" title="Research Data Management" target="_blank">
                {{ _("Research Data Management") }} <i class="external alternate icon"></i>
              </a>
            </div>
          </div>
        </div>

        <div class="column">
          <h2>{{ _("Accessibility") }}</h2>
          <div class="ui list">
            <div class="item">
              {{ _("Tipp:") }}
            </div>
            <div class="item">
              {{ _("Use Ctrl + and Crtl -") }}
            </div>
            <div class="item">
              {{ _("to change the font size.") }}
            </div>
          </div>
        </div>

      </div>

      <div class="ui divider"></div>

      <div class="doubling four column row">
        <div class="column">
          <div class="logos">
            <strong>Powered by</strong>
            <a href="http://inveniosoftware.org/products/rdm" target="_blank" title="invenioRDM">
              <img src="{{ url_for("static", filename="images/inveniordm-tail.svg")}}"
                 alt="InvenioRDM logo"
                 style="display: block; height: 90px; margin-top: 8px;">
            </a>
          </div>
        </div>
        <div class="column">
          <div class="logos">
            <strong>Enabled by</strong>
            <a href="https://forschungsdaten.at/en/fair-data-austria/" target="_blank" title="Fair Data Austria">
              <img src="{{ url_for("static", filename="images/Fair_Data_Austria_orangerot.png")}}"
                   alt="Fair Data Austria"
                   style="display: block; height: auto; margin-top: 15px; width: 230px;">
            </a>
          </div>
        </div>

        <div class="column">
          <div class="logos">
            <strong>Supported by</strong>
            <a href="https://www.openeducation.at" target="_blank" title="Open Education Austria">
              <img src="{{ url_for("static", filename="images/oea.svg")}}"
                   alt="Open Education Austria"
                   style="display: block; height: auto; margin-top: 15px; width: 200px;">
            </a>
          </div>
        </div>
      </div>

      <div class="ui divider"></div>

      <div class="doubling four column row">
        <div class="column">
          <div class="logos">
            <strong>Listed on</strong>
            <a href="https://www.re3data.org/repository/r3d100013565" target="_blank" title="Registry of Research Data Repositories">
              <img src="{{ url_for("static", filename="images/re3data.svg")}}"
                   alt="Registry of Research Data Repositories"
                   style="display: block; height: auto; width: 300px;">
            </a>
          </div>
        </div>
      </div>
    </div>
  </div>
</footer>
