{#
  Copyright (C) 2020-2023 Graz University of Technology.

  invenio-theme-iform is free software; you can redistribute it and/or
  modify it under the terms of the MIT License; see LICENSE file for more
  details.
#}

<div class="sixteen wide column random-records-frontpage">
  <div class="center aligned ui equal height grid">
    <div class="left aligned column">
      <div class="ui segment image">
        <h2>{{ _("Research Results") }}</h2>

        <div>
          {{ _("Frontpage: Description for research results") }}
        </div>

        <ul>
          {#
          <li>
            <a href="research-results/browse">{{ _("Browse") }}</a>
          </li>
          #}
          <li>
            <a href="records/search">{{ _("Search for research results") }}</a>
          </li>
          <li>
            <a href="me/uploads">{{ _("Upload research results") }}</a>
          </li>
        </ul>
      </div>
    </div>
    <div class="left aligned column">
      <div class="ui segment image">
        <h2>{{ _("Publications") }}</h2>

        <div>
          {{ _("Frontpage: Description for publications") }}
        </div>

        <ul>
          {#
          <li>
            <a href="publications/browse">Browse</a>
          </li>
          #}
          <li>
            <a href="publications/search">{{ _("Search for publications") }}</a>
          </li>
        </ul>
      </div>
    </div>
    <div class="left aligned column">
      <div class="ui segment image">
        <h2>{{ _("Educational Resources") }}</h2>

        <div>
          {{ _("Frontpage: Description for open educational resources") }}
        </div>

        <ul>
          {#
          <li>
            <a href="oer/browse">{{ _("Browse") }}</a>
          </li>
          #}
          <li>
            <a href="oer/search">{{ _("Search for educational resourses") }}</a>
          </li>
          <li>
            <a href="oer/uploads">{{ _("Upload educational resources") }}</a>
          </li>
        </ul>
      </div>
    </div>
  </div>
</div>
