{#
    Copyright (C) 2024 Graz University of Technology.

    invenio-theme-iform is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.
  #}

  {% extends config.THEME_ERROR_TEMPLATE %}

  {% block message %}
    <h1> {{ _('Internal server error') }} </h1>
    <p>
      {{ _(
          'Please contact <a href="mailto:{support_email}">our support</a>
          to let us know about this error.'
        ).format(support_email=config.THEME_IFORM_SUPPORT_EMAIL)
      }}
    </p>
    {# TODO: provide g.sentry_event_id here once sentry is configured, cf. invenio_theme/500.html #}
  {% endblock message %}
