/*
 * Copyright (C) 2020 Graz University of Technology
 *
 * invenio-theme-iform is free software; you can redistribute it and/or modify
 * it under the terms of the MIT License; see LICENSE file for more details.
 */

.top-bottom-padded {
    margin: unset;
}

.label.label-keyword {
    font-size: 0.71428571rem;
    font-weight: 400;
    background-color: @labelKeywordBackground;
    border: unset;
}
