/*
 * Copyright (C) 2020-2023 Graz University of Technology.
 *
 * invenio-theme-iform  is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

#footer {
    color: @footerGrey;
    min-height: 100%;
    width: 100%;

    &.footer-bottom {
        background-color: @footerBottomBackground;
        padding-top: 15px;
        padding-bottom: 15px;
        font-size: 16px;

        a {
            text-decoration: none;
            color: @footerGrey;

            // :focus-visible activates on keyboard only
            &:hover,
            &:focus:focus-visible {
                color: @primaryLink;
                background-color: @primaryLinkHoverBackground;

                i.icon.download {
                    color: @tugrazRed;
                }
            }

            // remove blue focus outline if clicked with mouse
            &:focus:not(:focus-visible) {
                outline-style: none;
            }
        }
    }

    div .logos a:hover {
        background-color: transparent !important;
    }
}

.bodytext {
    font-size: 16px;
}

.spacer {
    margin-top: 10px;
}

.spacer-long {
    margin-top: 30px;
}
