/*
 *   Copyright (C) 2022 Graz University of Technology.
 *
 * invenio-theme-iform  is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

.ui.container.page-subheader-outer {
    background-color: unset;
}

.ui.fluid.container {
    width: fit-content;
}
