/*
 * Copyright (C) 2020-2023 Graz University of Technology
 *
 * invenio-theme-iform is free software; you can redistribute it and/or modify
 * it under the terms of the MIT License; see LICENSE file for more details.
 */

.creators {
    margin: 0 0 1em;
}

.creators span {
    margin-left: 2px;
}

.creator:not(:last-child):after {
    color: @greyDark;
    content: ';';
}

.creator {
    display: inline-block;
    margin-right: 5px;
}

.identifiers {
    display: inline;
}
