/*
 *   Copyright (C) 2020-2021 Graz University of Technology.
 *
 * invenio-theme-iform  is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

/***
 * Logos background frontpage.
 * from rgba(173, 206, 224, 0.52)
 * to #ffffff
 ***/
.section-content-light-bg {
    background-color: @primaryBackground;
}

/***
 * section title.
 * from #0377cd
 * to #000000
 ***/
.section-title {
    color: @primaryText;
}


/***
 * login background color
 * from : rgba(13,95,137,.8)
 * To #ffffff
 ***/
.cover-page {
    //text-align: center;
    background-color: @primaryBackground;
}


/***
 * login & sigup page title
 * from : #0377cd
 * To #000000
 ***/
.panel-free-title {
    color: @primaryText;
}


/***
 * force: the font changes
 ***/
*,
html,
body,
h1,
h2,
h3,
h4,
h5,
h6,
pre,
.ui.button,
.ui.items,
.ui.accordion .title:not(.ui),
.ui.items>.item>.content>.header,
.ui.modal>.header,
.ui.menu,
.ui.header,
.ui.form input[type],
.ui.form input[type]:focus {
    font-family: "Source Sans Pro";
}

pre {
    font-size: 14px;
}


/***
 * search.button
 ***/
/*.ui.button,*/
.ui.search.button {
    background-color: @tugrazRed;
}

/***
 * accordion title
 ***/
.ui.accordion.styled {

    .title,
    .title.active {
        background-color: @greyLight;
        color: rgba(0, 0, 0, 0.6);
    }
}

/***
 * buttons hover and accordion hover
 ***/
.ui.button:hover,
.ui.search.button:hover,
.ui.accordion.styled .title:hover,
.ui.accordion.styled .accordion .title:hover {
    background-color: @primaryButtonHoverBackground;
    color: @primaryButton;
}

/***
 * force: remove corners from border
 ***/
.label-keyword,
.ui.label,
.ui.button,
.ui.rdm-sidebar,
.ui.menu,
.ui.input>input,
/* it seams redundant but it is not */
.ui.segment,
.ui.selection.dropdown,
.ui.accordion.styled,
.ui.card,
.ui.cards>.card,
.ui.basic.button,
.ui.basic.buttons .button,
.ui.action.input:not([class*="left action"])>.button:last-child,
.ui.action.input:not([class*="left action"])>.buttons:last-child>.button,
.ui.action.input:not([class*="left action"])>.dropdown:last-child,
.ui.form input[type],
.ui.form input[type]:focus {
    border-radius: 0;
}

/***
 * force: rdm-side-bar same empty box as on the frontpage
 ***/
.ui.rdm-sidebar {
    background-color: unset;
    box-shadow: unset;
}

/***
 * force: font weight: normal
 ***/
.ui.label {
    font-weight: 400;
}

// override access badges color
.ui.label.access-status {
    &.open {
        background-color: @accessRightOpen;
    }

    &.embargoed {
        background-color: @accessRightEmbargoed;
        ;
    }

    &.metadata-only {
        background-color: @accessRightMetadata;
    }
}

@font-face {
    font-family: "Source Sans Pro";
    src: url('./fonts/SourceSansPro/SourceSansPro-Regular.ttf') format('truetype');
    font-weight: 400;
    font-style: normal;
}

@font-face {
    font-family: "Source Sans Pro";
    src: url('./fonts/SourceSansPro/SourceSansPro-Italic.ttf') format('truetype');
    font-weight: 400;
    font-style: italic;
}

/**
 * mainly for the overview. maybe this should be written more specific to apply
 * only for the overview use case.
 */
.ui.segment:first-child {
    margin-top: 1em;
}

.ui.equal.height .ui.segment {
    height: 100%;
}

.ui.flashed.message.manage {
    text-align: center;
}
