/*
 *   Copyright (C) 2020 TUGRAZ.
 *   Copyright (C) 2020 Nikita Lvov.
 *
 * invenio-theme-iform  is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

.cover-page {
    //text-align: center;
    background-color: #ffffff;
}

#login-tug-logo {
    & g {
        fill: @tugrazRed;
    }
}

#login-tug-logo:hover {
    & g {
        fill: @tugrazBlack;
    }
}

.accounts-link {
    margin: 5%;
    color: @primaryLink;
    border: 1px solid @primaryLink;
    background-color: transparent;
}

.accounts-link :hover {
    font-size: smaller !important;
    color: @primaryLink;
    background-color: @primaryLinkHoverBackground !important;
}

.tu-button-style button {
    cursor: pointer;
    border: 1px solid @primaryButton;
    background-color: transparent;
    height: 29px;
    color: @primaryButton;
    font-family: "Source Sans Pro";
    font-weight: 300;
    font-size: 16px;
}

.tu-button-style button:hover {
    cursor: pointer;
    color: @primaryButton;
    background-color: @primaryButtonHoverBackground !important;
}

.form-accounts {
    margin: 15%;
    text-align: left !important;

    & i {
        color: @primaryFormAccounts !important;
    }

    & label {
        display: flex !important;
        font-weight: 300 !important;
        color: @primaryFormAccounts !important;
    }

    & input {
        border: 0px none !important;
        padding: 0px !important;
        border-bottom: 1px solid @primaryFormAccounts !important;
        background-color: transparent !important;
        color: @primaryFormAccounts !important;
        border-radius: 0 !important;
        width: 100% !important;
    }

    & input::placeholder {
        opacity: 1 !important;
        color: @formAccountsInputPlaceholder !important;
    }

    & th {
        display: block;
    }

    & td {
        display: inline-block;
    }
}

.field>input::selection {
    background: @fieldInputSelectionBackground;
}

.accounts-header {
    font-weight: 300 !important;
}

/***
login and sign-up pages form background color
*/
.sign-form {
    background-color: @signInBackground !important;
    padding: 0 !important;
    height: 100%;
}

.tug-button-login {
    display: flex;
    align-items: center;
    fill: @tugrazRed;
}

.tug-button-login :hover {
    fill: @primaryButtonHoverBackground;
}

.login-page-button {
    margin: 5%;
    text-align: center !important;

    & a {
        padding: 5px;
        text-decoration: underline !important;
        cursor: pointer;
    }

    & a:hover {
        background-color: @primaryLinkHoverBackground;
        color: @primaryLink !important;
        text-decoration: none;
    }
}

.login-page-button-white {
    color: @primaryButton !important;
    font-family: "Source Sans Pro";
    font-size: initial;
}

.login-page-button-black {
    color: @primaryButtonInverted !important;
    font-family: "Source Sans Pro";
    font-size: initial;
}

/***
allowing to switch columns on the sign-up page on the small screen
*/
.switch-grid {
    display: flex;
}

@media (max-width: 767px) {
    #switch_left {
        order: 2;
    }

    #switch_right {
        order: 1;
    }
}
