/*
 *   Copyright (C) 2020-2021 Graz University of Technology.
 *
 * invenio-theme-iform is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

/*
* authors.html
*/
.inline-orcid {
    height: 14px;
}

.text-muted {
    color: @greyDark;
}
