/*
 *   Copyright (C) 2021 Graz University of Technology.
 *
 * invenio-theme-iform is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

// deposit form segment styling
.ui.inverted.brand.segment {
    background-color: @greyLight !important;
    color: @tugrazBlack !important;

    label {
        color: @tugrazBlack;
    }
}
