/*
 *   Copyright (C) 2020-2021 Graz University of Technology.
 *
 * invenio-theme-iform  is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

h4 {
    display: block;
    margin-block-start: 0.33em;
    margin-block-end: 0.33em;
    margin-inline-start: 0px;
    margin-inline-end: 0px;
}

h2 {
    margin-block-start: 0.83em;
    margin-block-end: 0.83em;
    margin-inline-start: 0px;
    margin-inline-end: 0px;
}

.ui.blue.labels .label,
.ui.blue.label {
    color: @greyDark !important;
    background-color: @recordVersionBackground !important;
    border-color: @recordVersionBackground !important;
}

.random-records-frontpage article {
    border-bottom: 1px solid @randomRecordsFrontpageArticle;
    margin-bottom: 1rem;
    padding-bottom: 1rem;
}

.random-records-frontpage .more {
    margin-top: 20px !important;
    margin-bottom: 35px !important;
}

.random-records-frontpage h2 {
    text-align: center;
}

.badges {
    float: right;
}

/*Zammad form**/
.zammad-form {
    h2 {
        text-align: center;
    }

    .form-group {
        label {
            color: @tugrazBlack;
        }

        input.form-control {
            height: 30px;
            // width: auto;
            border-radius: 0;
            font-family: "Source Sans Pro";
            background: @primaryLinkBackgroundInverted;
            border: 1px solid rgba(34, 36, 38, 0.15);
        }

        textarea {
            border: 1px solid rgba(34, 36, 38, 0.15);
        }
    }

    .btn {
        width: 100% !important;
        cursor: pointer;
        font-family: "Source Sans Pro";
        min-height: 1em;
        line-height: 1em;
        padding: 0.78571429em 1.5em 0.78571429em;
        background: @greyLight none;
        border: 0;
    }

    .btn:hover {
        background: @primaryLinkHoverBackground;
        color: @primaryButton;
        font-size: 1rem;
        font-weight: bold;
    }
}

:focus {
    outline: thin;
    outline-style: solid;
    outline-color: @outlineColor;
}
