/*
 *   Copyright (C) 2020-2022 Graz University of Technology.
 *
 * invenio-theme-iform  is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

@import "variables";
@import "header";
@import "footer";
@import "overrides";
@import "frontpage";
@import "record";
@import "search";
@import "macros";
@import "login";
@import "deposit";
@import "communities";

/***
**TODO:
** test overriding variables.
***/

//@import "../invenio_app_rdm/theme";
//@import "variables";

// used in various templates
// add no hyperlink decoration
.no-decoration {
    color: inherit;
    text-decoration: none;
    transition: background-color 0.15s ease 0s, color 0.15s ease 0s;
    outline: none;
}

.nowrap-link {
    white-space: nowrap;
}

.ui.label.schema {
    border: 1px solid #bfb5b5;
}

.random-records-frontpage {}

.random-records-frontpage .grid .column {
    width: 380px !important;
    padding: 14px !important;
}
