{#
  Copyright (C) 2024 Graz University of Technology.

  invenio-theme-iform is free software; you can redistribute it and/or
  modify it under the terms of the MIT License; see LICENSE file for more
  details.
#}

{% extends config.THEME_ERROR_TEMPLATE %}

{% block message %}
  <h1><i class="bolt icon"></i> {{_("Locked")}}</h1>
  <p>{{_("The resource that is being accessed is locked.")}}</p>
{% endblock message %}
