/*
 *   Copyright (C) 2020-2021 Graz University of Technology.
 *
 * invenio-theme-iform  is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

#int-menu-q-home-icon {
    width: 18px;
    height: 18px;
    vertical-align: top;
    fill: @tugrazRed;
}

/*****logo section******/
.affiliation-logo {
    vertical-align: middle;
    white-space: nowrap;

    & a {
        fill: @tugrazRed;
    }
}

.affiliation-logo :hover {
    text-decoration: none;
    fill: @primaryLinkHoverBackground;
    color: @primaryLinkHoverBackground;
}

.affiliation {
    background-color: @primaryLink;
    display: table;
    margin: 0 auto 80px;
    max-width: 1060px;
    width: 100%;
    text-decoration: none;
}

.affiliation-text {
    display: table-cell;
    font-size: 12px;
    line-height: 17px;
    letter-spacing: 2px;
    white-space: nowrap;
}

.affiliation-logo-claim {
    display: inline-block;
    font-size: 12px;
    letter-spacing: 2px;
    line-height: 17px;
    padding: 0 17px 0 0;
    text-align: right;
    vertical-align: top;
}

/*****END logo section******/

.short-menu {
    display: table;
    height: 49px;
    width: 100%;
}

.short-menu-left {
    border-right: 1px solid black;
    display: table-cell;
    text-align: right;
    width: 50%;
}

.short-menu-right {
    display: table-cell;
    width: 50%;
    color: @primaryLinkInverted;
}

.short-menu-right :hover {
    background-color: @primaryLinkHoverBackground;
    color: @primaryLink;
}

.short-menu-right-button {
    cursor: pointer;
    display: inline-block;
    margin: 12px 0 6px 9px;
    padding: 5px;
}

.short-menu-right-button a:hover {
    text-decoration: none;
}

.short-menu-left-lang {
    display: inline-block;
    margin-right: 10px;
    font-size: 17px !important;
    font-weight: 300;

    & a {
        padding: 5px;
        background-color: transparent;
        color: @primaryLinkInverted;
        text-decoration: none;
    }
}

.short-menu-left-lang:hover {
    & a {
        background-color: @primaryLinkHoverBackground;
        color: @primaryLink;
        text-decoration: none;
    }
}

.search-icon-header {
    display: inline-block;

    & a {
        background-color: transparent;
        padding: 5px;
        text-decoration: none;

        & svg {
            & g {
                stroke-linejoin: round;
                stroke: @primaryLinkInverted;
                stroke-miterlimit: 10;
                stroke-width: 2;
                fill: none;
            }
        }
    }
}

.search-icon-header:hover {
    & a {
        background-color: @primaryLinkHoverBackground;
        text-decoration: none;

        & svg {
            & g {
                stroke: @primaryLink;
            }
        }
    }
}

.short-menu-left-search {
    display: inline-block;
    margin: 12px 9px 6px 0;
    color: @primaryLinkInverted;
}

.short-menu-right-main-menu {
    display: inline-block;
    margin-right: 3px;
    vertical-align: top;
    width: 21px;
}

.short-menu-icon {
    vertical-align: top;
    width: 20px;
    height: 19px;
}

svg:not(:root) {
    overflow: hidden;
}

/***********MAIN menu*************/

.main-menu-entry {
    text-align: center !important;

    & a {
        font-size: 1.2rem;
        padding: 5px 8px;
    }
}

.main-menu-entry a:hover {
    background-color: @primaryLinkHoverBackground;
    color: @primaryLink;
    text-decoration: none;
}

.main-menu-entry-svg {
    padding-left: 0 !important;
}

.main-menu-underline-line {
    border: 2px solid @greyLight !important;
    border-radius: 0;
    background-color: @greyLight;
}

#margin-divider {
    margin-left: 155px;
    margin-right: 155px;
}

.affiliation-text a:hover {
    background-color: @primaryLinkHoverBackground;
    color: @primaryLink;
    text-decoration: none;
}

.main-menu {
    border-bottom: 1px solid @primaryLinkInverted;
    box-sizing: border-box;
    height: 39px;
    margin-top: -1px;
    overflow: hidden;
    transition: height 0.3s linear 0s;
}

.int-menu-q-open-icon {
    width: 14px;
    vertical-align: middle;
    margin-left: 5px;
}

/*********************Custom overrides**********************/
/** Login with SAML**/
.col a {
    cursor: pointer;
}

@media screen and (max-width: 767.9px) {
    #int-header-logo-img {
        width: 200px;
        height: 75px;
    }

    #main-logo {
        padding: 30px 0;
        text-align: center;
        display: block;
    }

    #repo-logo {
        display: none;
    }

    .affiliation-logo-claim {
        display: none;
    }
}

.repo-img {
    margin-right: 5px;
}

.inline-elements {
    display: flex;
}

span.home-inline {
    white-space: nowrap;
}

.test-instance {
    text-align: center;
    background-color: @notificationBackground;
    border: solid @notificationBorder 1px;
    z-index: 100000;
}

#skip-to-main {
    background-color: @primaryButton;

    &:focus {
        background-color: @primaryButtonInverted;
    }
}
