/*
 *   Copyright (C) 2020-2021 Graz University of Technology.
 *
 * invenio-theme-iform  is free software; you can redistribute it and/or modify it
 * under the terms of the MIT License; see LICENSE file for more details.
 */

/***
**TODO:
** test overriding variables.
***/

//@import "../invenio_app_rdm/variables.less";
//@navbar_background_image: unset;
//@navbar_background_color: #ffffff;


// badge colors, accessibility
@accessRight : #e9711c;
@accessRightOpen : @accessRight;
@accessRightRestricted: #fbbd08;
@accessRightEmbargoed : #db2828;
@accessRightClosed : @accessRightEmbargoed;
@accessRightMetadata : #2185D0;

@schema: #17b3f3;

// primary colors TU Graz
@tugrazBlack : #00e66c;
@tugrazRed: #2250fc;

// general
@primaryBackground: #fff;
@primaryText : #000;


// accent colors
@greyDark : #777;
@greyLight : #E0E1E2;
@labelKeywordBackground: #E8E8E8;



// link and button colors
@primaryLinkInverted : @primaryText;
@primaryLinkBackgroundInverted: @primaryBackground;
@primaryLink : @primaryBackground;
@primaryLinkHoverBackground : @primaryText;
@primaryButton : @primaryBackground;
@primaryButtonHoverBackground : @primaryText;
@primaryButtonInverted : @primaryText;




// account (signin, signup) specific
@primaryFormAccounts : @primaryBackground;
@formAccountsInputPlaceholder : silver;
@fieldInputSelectionBackground: #50a2ce;
@signInBackground : #245b78;

// footer specific
@footerGrey : #5E5E5E;
@footerBottomBackground: #f2f2f2;

// record specific
@recordVersionBackground : #f2f2f2;
@randomRecordsFrontpageArticle: rgba(34, 36, 38, .15);

// input
@outlineColor: #85B7D9;

// notification
@notificationBackground: #fffaf3;
@notificationBorder: #e2d5c2;
