{#
  Copyright (C) 2020-2023 Graz University of Technology.

  invenio-theme-iform is free software; you can redistribute it and/or
  modify it under the terms of the MIT License; see LICENSE file for more
  details.
#}

{%- extends config.INVENIO_THEME_IFORM_BASE_TEMPLATE %}

{%- block javascript %}
  {{ webpack['invenio-theme-iform-js.js'] }}
{%- endblock javascript %}

{%- block page_body %}

<div class="ui container">
  <div class="ui divider hidden"></div>

  <div class="ui stackable grid">

    {% include "invenio_theme_iform/frontpage_overview.html" %}

    {% include "invenio_theme_iform/recent_uploads.html" %}

    <!---segments-->
    <div class="six wide column">
      {% include "invenio_theme_iform/contact_us.html" %}
      {% include "invenio_theme_iform/benefits.html" %}
    </div>
  </div>
</div>


{%- endblock %}
